==> seedsui-react-5.8.10.tgz: package/lib/Attach/Attach.js <==
var _excluded = ["label", "list", "uploading", "onChoose", "onDelete", "onClick", "uploadProps", "itemProps"];
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
// require (PrototypeString.js), 使用了getSuffix
import React, { forwardRef, useRef, useImperativeHandle } from 'react';
import locale from "./../locale";
var Attach = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var label = _ref.label,
    list = _ref.list,
    uploading = _ref.uploading,
    onChoose = _ref.onChoose,
    onDelete = _ref.onDelete,
    onClick = _ref.onClick,
    uploadProps = _ref.uploadProps,
    itemProps = _ref.itemProps,
    props = _objectWithoutProperties(_ref, _excluded);
  // 节点
  var rootRef = useRef(null);
  useImperativeHandle(ref, function () {
    return {
      rootDOM: rootRef.current,
      getRootDOM: function getRootDOM() {
        return rootRef.current;
      }
    };
  });

  // 获取附件类型图标
  function getIcon(src) {
    var suffix = typeof src === 'string' ? src.getSuffix() : null;
    if (!suffix) return 'unknown';
    if (suffix.indexOf('?') !== -1) {
      suffix = suffix.substring(0, suffix.indexOf('?'));
    }
    if ('RM,RMVB,MP4,3GP,AVI,MKV,WMV,MPG,VOB,FLV'.indexOf(suffix.toUpperCase()) !== -1) {
      return 'video';
    }
    if ('WAVE,MPEG,MP3,MPEG-4,MIDI,WMA,VQF,AMR,APE,FLAC,AAC'.indexOf(suffix.toUpperCase()) !== -1) {
      return 'audio';
    }
    if ('JPG,JPEG,WEBP,GIF,PNG,TIF,BMP'.indexOf(suffix.toUpperCase()) !== -1) {
      return 'pic';
    }
    if ('RAR,ZIP'.indexOf(suffix.toUpperCase()) !== -1) {
      return 'pack';
    }
    if ('DOC,DOCX'.indexOf(suffix.toUpperCase()) !== -1) {
      return 'word';
    }
    if ('XSL,EXCEL'.indexOf(suffix.toUpperCase()) !== -1) {
      return 'excel';
    }
    if ('PPT'.indexOf(suffix.toUpperCase()) !== -1) {
      return 'ppt';
    }
    if ('PDF'.indexOf(suffix.toUpperCase()) !== -1) {
      return 'pdf';
    }
    return 'unknown';
  }
  function handleClick(e) {
    var target = e.target;
    if (target.classList.contains('attach-item')) {
      // 点击一行
      var index = target.getAttribute('data-index');
      if (index && onClick) onClick(e, list[index].src, [list[index]], Number(index));
    } else if (target.classList.contains('attach-item-delete')) {
      // 点击删除
      var _index = target.parentNode.getAttribute('data-index');
      if (_index && onDelete) onDelete(e, list[_index].src, [list[_index]], Number(_index));
    }
  }
  // file框选择
  function handleFileChange(e) {
    if (onChoose) onChoose(e);
    e.target.value = ''; // 防止选择重复图片时不触发
    e.stopPropagation();
  }
  return /*#__PURE__*/React.createElement("div", _extends({}, props, {
    className: "attach".concat(uploading ? ' uploading' : '').concat(props.className ? ' ' + props.className : ''),
    onClick: handleClick,
    ref: rootRef
  }), onChoose && /*#__PURE__*/React.createElement("div", _extends({}, uploadProps, {
    className: "attach-upload".concat(uploadProps !== null && uploadProps !== void 0 && uploadProps.className ? ' ' + uploadProps.className : '')
  }), /*#__PURE__*/React.createElement("input", {
    type: "file",
    name: "uploadAttach",
    onChange: handleFileChange
  }), /*#__PURE__*/React.createElement("i", {
    className: "attach-upload-icon"
  }), /*#__PURE__*/React.createElement("div", {
    className: "attach-upload-loading"
  }, /*#__PURE__*/React.createElement("div", {
    className: "attach-upload-loading-icon"
  }, /*#__PURE__*/React.createElement("svg", {
    viewBox: "25 25 50 50"
  }, /*#__PURE__*/React.createElement("circle", {
    cx: "50",
    cy: "50",
    r: "20"
  })))), /*#__PURE__*/React.createElement("div", {
    className: "attach-upload-label"
  }, label || locale('附件', 'attach'))), list && list.length > 0 && list.map(function (item, index) {
    return /*#__PURE__*/React.createElement("div", _extends({
      key: index,
      "data-index": index,
      className: "attach-item".concat(item.className ? ' ' + item.className : ''),
      style: item.style || {}
    }, itemProps), /*#__PURE__*/React.createElement("i", {
      className: "icon attach-item-type ".concat(getIcon(item.src))
    }), /*#__PURE__*/React.createElement("div", {
      className: "attach-item-label"
    }, item.name || item.src), onDelete && /*#__PURE__*/React.createElement("i", {
      className: "attach-item-delete"
    }), item.children);
  }));
});
export default Attach;

==> seedsui-react-5.8.44.tgz: package/lib/Attach/Attach.js <==
var _excluded = ["label", "list", "uploading", "onChoose", "onDelete", "onClick", "uploadProps", "itemProps"];
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
// require (PrototypeString.js), 使用了getSuffix
import React, { forwardRef, useRef, useImperativeHandle } from 'react';
import locale from "./../locale";

/**
 * @deprecated since version 5.4.9
 * 请使用Upload
 */
var Attach = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var label = _ref.label,
    list = _ref.list,
    uploading = _ref.uploading,
    onChoose = _ref.onChoose,
    onDelete = _ref.onDelete,
    onClick = _ref.onClick,
    uploadProps = _ref.uploadProps,
    itemProps = _ref.itemProps,
    props = _objectWithoutProperties(_ref, _excluded);
  // 节点
  var rootRef = useRef(null);
  useImperativeHandle(ref, function () {
    return {
      rootDOM: rootRef.current,
      getRootDOM: function getRootDOM() {
        return rootRef.current;
      }
    };
  });

  // 获取附件类型图标
  function getIcon(src) {
    var suffix = typeof src === 'string' ? src.getSuffix() : null;
    if (!suffix) return 'unknown';
    if (suffix.indexOf('?') !== -1) {
      suffix = suffix.substring(0, suffix.indexOf('?'));
    }
    if ('RM,RMVB,MP4,3GP,AVI,MKV,WMV,MPG,VOB,FLV'.indexOf(suffix.toUpperCase()) !== -1) {
      return 'video';
    }
    if ('WAVE,MPEG,MP3,MPEG-4,MIDI,WMA,VQF,AMR,APE,FLAC,AAC'.indexOf(suffix.toUpperCase()) !== -1) {
      return 'audio';
    }
    if ('JPG,JPEG,WEBP,GIF,PNG,TIF,BMP'.indexOf(suffix.toUpperCase()) !== -1) {
      return 'pic';
    }
    if ('RAR,ZIP'.indexOf(suffix.toUpperCase()) !== -1) {
      return 'pack';
    }
    if ('DOC,DOCX'.indexOf(suffix.toUpperCase()) !== -1) {
      return 'word';
    }
    if ('XSL,EXCEL'.indexOf(suffix.toUpperCase()) !== -1) {
      return 'excel';
    }
    if ('PPT'.indexOf(suffix.toUpperCase()) !== -1) {
      return 'ppt';
    }
    if ('PDF'.indexOf(suffix.toUpperCase()) !== -1) {
      return 'pdf';
    }
    return 'unknown';
  }
  function handleClick(e) {
    var target = e.target;
    if (target.classList.contains('attach-item')) {
      // 点击一行
      var index = target.getAttribute('data-index');
      if (index && onClick) onClick(e, list[index].src, [list[index]], Number(index));
    } else if (target.classList.contains('attach-item-delete')) {
      // 点击删除
      var _index = target.parentNode.getAttribute('data-index');
      if (_index && onDelete) onDelete(e, list[_index].src, [list[_index]], Number(_index));
    }
  }
  // file框选择
  function handleFileChange(e) {
    if (onChoose) onChoose(e);
    e.target.value = ''; // 防止选择重复图片时不触发
    e.stopPropagation();
  }
  return /*#__PURE__*/React.createElement("div", _extends({}, props, {
    className: "attach".concat(uploading ? ' uploading' : '').concat(props.className ? ' ' + props.className : ''),
    onClick: handleClick,
    ref: rootRef
  }), onChoose && /*#__PURE__*/React.createElement("div", _extends({}, uploadProps, {
    className: "attach-upload".concat(uploadProps !== null && uploadProps !== void 0 && uploadProps.className ? ' ' + uploadProps.className : '')
  }), /*#__PURE__*/React.createElement("input", {
    type: "file",
    name: "uploadAttach",
    onChange: handleFileChange
  }), /*#__PURE__*/React.createElement("i", {
    className: "attach-upload-icon"
  }), /*#__PURE__*/React.createElement("div", {
    className: "attach-upload-loading"
  }, /*#__PURE__*/React.createElement("div", {
    className: "attach-upload-loading-icon"
  }, /*#__PURE__*/React.createElement("svg", {
    viewBox: "25 25 50 50"
  }, /*#__PURE__*/React.createElement("circle", {
    cx: "50",
    cy: "50",
    r: "20"
  })))), /*#__PURE__*/React.createElement("div", {
    className: "attach-upload-label"
  }, label || locale('附件', 'SeedsUI_attach'))), list && list.length > 0 && list.map(function (item, index) {
    return /*#__PURE__*/React.createElement("div", _extends({
      key: index,
      "data-index": index,
      className: "attach-item".concat(item.className ? ' ' + item.className : ''),
      style: item.style || {}
    }, itemProps), /*#__PURE__*/React.createElement("i", {
      className: "icon attach-item-type ".concat(getIcon(item.src))
    }), /*#__PURE__*/React.createElement("div", {
      className: "attach-item-label"
    }, item.name || item.src), onDelete && /*#__PURE__*/React.createElement("i", {
      className: "attach-item-delete"
    }), item.children);
  }));
});
export default Attach;
